@@ -31,7 +31,6 @@ using System.Globalization;
 using System.Reflection;
 using System.Threading;
 using System.Text;
-using System.Text.RegularExpressions;
 using System.Runtime.InteropServices;
 
 using GLib;
@@ -70,8 +69,12 @@ public class QueryTool {
 					   (lastQueryTime - queryStartTime).TotalSeconds);
 		}
 
-		if (verbose && response.NumMatches >= 0)
-			Console.WriteLine ("Returned latest {0} results out of total {1} matches", response.Hits.Count, response.NumMatches);
+		if (verbose) {
+			if (response.NumMatches >= 0)
+				Console.WriteLine ("Returned latest {0} results out of total {1} matches", response.Hits.Count, response.NumMatches);
+			else
+				Console.WriteLine ("Returned latest {0} results", response.Hits.Count);
+		}
 
 		if (! display_hits) {
 			count += response.Hits.Count;
@@ -194,46 +197,6 @@ public class QueryTool {
 		System.Environment.Exit (0);
 	}
 
-	private static void ReadBackendMappings ()
-	{
-		ArrayList assemblies = ReflectionFu.ScanEnvironmentForAssemblies ("BEAGLE_BACKEND_PATH", PathFinder.BackendDir);
-
-		// Add BeagleDaemonLib if it hasn't already been added.
-		bool found_daemon_lib = false;
-		foreach (Assembly assembly in assemblies) {
-			if (assembly.GetName ().Name == "BeagleDaemonLib") {
-				found_daemon_lib = true;
-				break;
-			}
-		}
-
-		if (!found_daemon_lib) {
-			try {
-				assemblies.Add (Assembly.LoadFrom (Path.Combine (PathFinder.PkgLibDir, "BeagleDaemonLib.dll")));
-			} catch (FileNotFoundException) {
-				Console.WriteLine ("WARNING: Could not find backend list.");
-				Environment.Exit (1);
-			}
-		}
-
-		foreach (Assembly assembly in assemblies) {
-			foreach (Type type in ReflectionFu.GetTypesFromAssemblyAttribute (assembly, typeof (IQueryableTypesAttribute))) {
-				object[] attributes = type.GetCustomAttributes (false);
-				foreach (object attribute in attributes) {
-					PropertyKeywordMapping mapping = attribute as PropertyKeywordMapping;
-					if (mapping == null)
-						continue;
-					//Logger.Log.Debug (mapping.Keyword + " => " 
-					//		+ mapping.PropertyName + 
-					//		+ " is-keyword=" + mapping.IsKeyword + " (" 
-					//		+ mapping.Description + ") "
-					//		+ "(" + type.FullName + ")");
-					PropertyKeywordFu.RegisterMapping (mapping);
-				}
-			}
-		}
-	}
-
 	private static void OnClosed ()
 	{
 		if (flood)
@@ -314,17 +277,16 @@ public class QueryTool {
 				keep_running = true;
 				break;
 			case "--keywords":
-				ReadBackendMappings ();
-				QueryDriver.ReadKeywordMappings ();
+				PropertyKeywordFu.ReadKeywordMappings ();
 
 				Console.WriteLine ("Supported query keywords are:");
 
 				foreach (string key in PropertyKeywordFu.Keys) {
-					foreach (PropertyDetail prop in PropertyKeywordFu.Properties (key)) {
+					foreach (QueryKeywordMapping mapping in PropertyKeywordFu.Properties (key)) {
 						// Dont print properties without description; they confuse people
-						if (string.IsNullOrEmpty (prop.Description))
+						if (string.IsNullOrEmpty (mapping.Description))
 							continue;
-						Console.WriteLine ("  {0,-20} for {1}", key, prop.Description);
+						Console.WriteLine ("  {0,-20} for {1}", key, mapping.Description);
 					}
 				}
 
@@ -370,4 +332,3 @@ public class QueryTool {
 		main_loop.Run ();
 	}
 }
-	
